@@ -25,7 +25,8 @@ from tendenci.addons.memberships.models import (MembershipType, App,
                                                 MembershipApp,
                                                 MembershipDefault,
                                                 Membership)
-from tendenci.apps.forms_builder.forms.settings import FIELD_MAX_LENGTH, LABEL_MAX_LENGTH
+from tendenci.apps.forms_builder.forms.settings import (FIELD_MAX_LENGTH,
+                                                        LABEL_MAX_LENGTH)
 from tendenci.addons.corporate_memberships.managers import (
                                                 CorporateMembershipManager,
                                                 CorpMembershipManager,
@@ -54,12 +55,15 @@ FIELD_CHOICES = (
                     ("CharField/django.forms.Textarea", _("Paragraph Text")),
                     ("BooleanField", _("Checkbox")),
                     ("ChoiceField", _("Select One from a list (Drop Down)")),
-                    ("ChoiceField/django.forms.RadioSelect", _("Select One from a list (Radio Buttons)")),
+                    ("ChoiceField/django.forms.RadioSelect",
+                        _("Select One from a list (Radio Buttons)")),
                     ("MultipleChoiceField", _("Multi select (Drop Down)")),
-                    ("MultipleChoiceField/django.forms.CheckboxSelectMultiple", _("Multi select (Checkboxes)")),
+                    ("MultipleChoiceField/django.forms.CheckboxSelectMultiple",
+                        _("Multi select (Checkboxes)")),
                     ("EmailField", _("Email")),
                     ("FileField", _("File upload")),
-                    ("DateField/django.forms.extras.SelectDateWidget", _("Date")),
+                    ("DateField/django.forms.extras.SelectDateWidget",
+                        _("Date")),
                     ("DateTimeField", _("Date/time")),
                     ("section_break", _("Section Break")),
                     ("page_break", _("Page Break")),
@@ -87,32 +91,42 @@ class CorporateMembershipType(OrderingBaseModel, TendenciBaseModel):
     guid = models.CharField(max_length=50)
     name = models.CharField(_('Name'), max_length=255, unique=True)
     description = models.CharField(_('Description'), max_length=500)
-    price = models.DecimalField(_('Price'), max_digits=15, decimal_places=2, blank=True, default=0,
+    price = models.DecimalField(_('Price'), max_digits=15, decimal_places=2,
+                                blank=True, default=0,
                                 help_text="Set 0 for free membership.")
-    renewal_price = models.DecimalField(_('Renewal Price'), max_digits=15, decimal_places=2, 
+    renewal_price = models.DecimalField(_('Renewal Price'), max_digits=15,
+                                        decimal_places=2,
                                         blank=True, default=0, null=True,
                                         help_text="Set 0 for free membership.")
-    membership_type = models.ForeignKey(MembershipType, 
-                                        help_text=_("Bind individual memberships to this membership type.")) 
-    
-    admin_only = models.BooleanField(_('Admin Only'), default=0)  # from allowuseroption
-    
-    apply_threshold = models.BooleanField(_('Allow Threshold'), default=0)
-    individual_threshold = models.IntegerField(_('Threshold Limit'), default=0, blank=True, null=True)
-    individual_threshold_price = models.DecimalField(_('Threshold Price'), max_digits=15, 
-                                                     decimal_places=2, blank=True, null=True, default=0,
-                                                     help_text=_("All individual members applying under or " + \
-                                                                 "equal to the threashold limit receive the " + \
-                                                                 "threshold prices."))
-    
+    membership_type = models.ForeignKey(MembershipType,
+        help_text=_("Bind individual memberships to this membership type."))
+    admin_only = models.BooleanField(_('Admin Only'), default=0)
+
+    apply_threshold = models.BooleanField(_('Allow Threshold'), default=False)
+    individual_threshold = models.IntegerField(_('Threshold Limit'),
+                                               default=0,
+                                               blank=True,
+                                               null=True)
+    individual_threshold_price = models.DecimalField(
+                                 _('Threshold Price'),
+                                 max_digits=15,
+                                 decimal_places=2,
+                                 blank=True,
+                                 null=True,
+                                 default=0,
+                                 help_text=_(
+                                 "All individual members applying " + \
+                                 "under or equal to the threashold " + \
+                                 "limit receive the threshold prices."))
+
     def __unicode__(self):
         return self.name
-    
+
     def save(self, *args, **kwargs):
         if not self.id:
             self.guid = str(uuid.uuid1())
         super(CorporateMembershipType, self).save(*args, **kwargs)
-      
+
     # added here temporarily because i cannot use the one in memberships now
     # switch later if the function in memberships is restored.
     def get_expiration_dt(self, renewal=False, join_dt=None, renew_dt=None):
@@ -120,47 +134,54 @@ class CorporateMembershipType(OrderingBaseModel, TendenciBaseModel):
         Calculate the expiration date - for join or renew (renewal=True)
         Examples:
             For join:
-                expiration_dt = corporate_membership_type.get_expiration_dt(join_dt=membership.join_dt)
+                expiration_dt = corporate_membership_type.get_expiration_dt(
+                                    join_dt=membership.join_dt)
             For renew:
-                expiration_dt = corporate_membership_type.get_expiration_dt(renewal=1,
-                join_dt=membership.join_dt,
-                renew_dt=membership.renew_dt)
+                expiration_dt = corporate_membership_type.get_expiration_dt(
+                                        renewal=1,
+                                        join_dt=membership.join_dt,
+                                        renew_dt=membership.renew_dt)
         """
         mt = self.membership_type
         now = datetime.now()
-        
+
         if not join_dt or not isinstance(join_dt, datetime):
             join_dt = now
         if renewal and (not renew_dt or not isinstance(renew_dt, datetime)):
             renew_dt = now
-        
+
         if mt.never_expires:
             return None
-        
+
         if mt.period_type == 'rolling':
             if mt.period_unit == 'days':
                 return now + timedelta(days=mt.period)
-            
+
             elif mt.period_unit == 'months':
                 return now + relativedelta(months=mt.period)
-            
-            else: # if self.period_unit == 'years':
+
+            else:  # if self.period_unit == 'years':
                 if not renewal:
                     if mt.rolling_option == '0':
                         # expires on end of full period
                         return join_dt + relativedelta(years=mt.period)
-                    else: # self.expiration_method == '1':
+                    else:   # self.expiration_method == '1':
                         # expires on ? days at signup (join) month
                         if not mt.rolling_option1_day:
                             mt.rolling_option1_day = 1
-                        expiration_dt = join_dt + relativedelta(years=mt.period)
-                        mt.rolling_option1_day = day_validate(datetime(expiration_dt.year, join_dt.month, 1),
-                                                                    mt.rolling_option1_day)
-                        
+                        expiration_dt = join_dt + relativedelta(
+                                                    years=mt.period)
+                        mt.rolling_option1_day = day_validate(
+                                                datetime(expiration_dt.year,
+                                                         join_dt.month, 1),
+                                                mt.rolling_option1_day)
+
                         return datetime(expiration_dt.year, join_dt.month,
-                                                 mt.rolling_option1_day, expiration_dt.hour,
-                                                 expiration_dt.minute, expiration_dt.second)
-                else: # renewal = True
+                                                 mt.rolling_option1_day,
+                                                 expiration_dt.hour,
+                                                 expiration_dt.minute,
+                                                 expiration_dt.second)
+                else:   # renewal = True
                     if mt.rolling_renew_option == '0':
                         # expires on the end of full period
                         return renew_dt + relativedelta(years=mt.period)
@@ -168,25 +189,34 @@ class CorporateMembershipType(OrderingBaseModel, TendenciBaseModel):
                         # expires on the ? days at signup (join) month
                         if not mt.rolling_renew_option1_day:
                             mt.rolling_renew_option1_day = 1
-                        expiration_dt = renew_dt + relativedelta(years=mt.period)
-                        mt.rolling_renew_option1_day = day_validate(datetime(expiration_dt.year, join_dt.month, 1),
-                                                                    mt.rolling_renew_option1_day)
+                        expiration_dt = renew_dt + relativedelta(
+                                                    years=mt.period)
+                        mt.rolling_renew_option1_day = day_validate(
+                                            datetime(expiration_dt.year,
+                                                     join_dt.month, 1),
+                                            mt.rolling_renew_option1_day)
                         return datetime(expiration_dt.year, join_dt.month,
-                                                 mt.rolling_renew_option1_day, expiration_dt.hour,
-                                                 expiration_dt.minute, expiration_dt.second)
+                                                 mt.rolling_renew_option1_day,
+                                                 expiration_dt.hour,
+                                                 expiration_dt.minute, 
+                                                 expiration_dt.second)
                     else:
                         # expires on the ? days at renewal month
                         if not mt.rolling_renew_option2_day:
                             mt.rolling_renew_option2_day = 1
-                        expiration_dt = renew_dt + relativedelta(years=mt.period)
-                        mt.rolling_renew_option2_day = day_validate(datetime(expiration_dt.year, renew_dt.month, 1),
-                                                                    mt.rolling_renew_option2_day)
+                        expiration_dt = renew_dt + relativedelta(
+                                                    years=mt.period)
+                        mt.rolling_renew_option2_day = day_validate(
+                                                datetime(expiration_dt.year,
+                                                         renew_dt.month, 1),
+                                                mt.rolling_renew_option2_day)
                         return datetime(expiration_dt.year, renew_dt.month,
-                                                 mt.rolling_renew_option2_day, expiration_dt.hour,
-                                                 expiration_dt.minute, expiration_dt.second)
-                    
-                    
-        else: #self.period_type == 'fixed':
+                                                 mt.rolling_renew_option2_day,
+                                                 expiration_dt.hour,
+                                                 expiration_dt.minute,
+                                                 expiration_dt.second)
+
+        else:    # self.period_type == 'fixed':
             if mt.fixed_option == '0':
                 # expired on the fixed day, fixed month, fixed year
                 if not mt.fixed_option1_day:
@@ -197,14 +227,15 @@ class CorporateMembershipType(OrderingBaseModel, TendenciBaseModel):
                     mt.fixed_option1_month = 12
                 if not mt.fixed_option1_year:
                     mt.fixed_option1_year = now.year
-                    
-                mt.fixed_option1_day = day_validate(datetime(mt.fixed_option1_year,
-                                                                  mt.fixed_option2_month, 1),
-                                                                    mt.fixed_option2_day)
-                    
+
+                mt.fixed_option1_day = day_validate(
+                                    datetime(mt.fixed_option1_year,
+                                          mt.fixed_option2_month, 1),
+                                    mt.fixed_option2_day)
+
                 return datetime(mt.fixed_option1_year, mt.fixed_option1_month,
                                 mt.fixed_option1_day)
-            else: # self.fixed_option == '1'
+            else:   # self.fixed_option == '1'
                 # expired on the fixed day, fixed month of current year
                 if not mt.fixed_option2_day:
                     mt.fixed_option2_day = 1
@@ -212,11 +243,12 @@ class CorporateMembershipType(OrderingBaseModel, TendenciBaseModel):
                     mt.fixed_option2_month = 1
                 if mt.fixed_option2_month > 12:
                     mt.fixed_option2_month = 12
-                
-                mt.fixed_expiration_day2 = day_validate(datetime(now.year,
-                                                                mt.fixed_option2_month, 1),
-                                                                mt.fixed_option2_day)
-                
+
+                mt.fixed_expiration_day2 = day_validate(
+                                                datetime(now.year,
+                                                mt.fixed_option2_month, 1),
+                                                mt.fixed_option2_day)
+
                 expiration_dt = datetime(now.year, mt.fixed_option2_month,
                                         mt.fixed_option2_day)
                 if mt.fixed_option2_can_rollover:
@@ -224,7 +256,7 @@ class CorporateMembershipType(OrderingBaseModel, TendenciBaseModel):
                         mt.fixed_option2_rollover_days = 0
                     if (now - expiration_dt).days <= mt.fixed_option2_rollover_days:
                         expiration_dt = expiration_dt + relativedelta(years=1)
-                        
+
                 return expiration_dt
 
 
@@ -633,7 +665,7 @@ class CorpMembership(TendenciBaseModel):
         field_names = [field.name for field in self.__class__._meta.fields]
         ignore_fields = ['id', 'renewal', 'renew_dt', 'status',
                          'status_detail', 'approved', 'approved_denied_dt',
-                         'approved_denied_user']
+                         'approved_denied_user', 'anonymous_creator']
         for field in ignore_fields:
             field_names.remove(field)
 
@@ -766,15 +798,19 @@ class CorpMembership(TendenciBaseModel):
                 # update the membership record with the renewal info
                 new_membership.renewal = True
                 new_membership.renew_dt = self.renew_dt
-                new_membership.expiration_dt = self.expiration_dt
+                new_membership.expire_dt = self.expiration_dt
                 new_membership.corporate_membership_id = self.id
                 new_membership.corp_profile_id = self.corp_profile.id
-                new_membership.membership_type = self.corporate_membership_type.membership_type
+                new_membership.membership_type = \
+                    self.corporate_membership_type.membership_type
                 new_membership.status = True
                 new_membership.status_detail = 'active'
+                new_membership.application_approved = True
+                new_membership.application_approved_dt = self.approved_denied_dt
                 if not request_user.is_anonymous():
                     new_membership.owner_id = request_user.id
                     new_membership.owner_username = request_user.username
+                    new_membership.application_approved_user = request_user
 
                 new_membership.save()
                 # archive old memberships
@@ -885,11 +921,18 @@ class CorpMembership(TendenciBaseModel):
             self.owner = assign_to_user
             self.owner_username = assign_to_user.username
             self.save()
-            corp_membership_update_perms(self)
 
-            # TODO:
-            # assign object permissions
-#            corp_memb_update_perms(self)
+            # assign creator to be dues_rep
+            if not CorpMembershipRep.objects.filter(
+                                    corp_profile=self.corp_profile,
+                                    user=self.creator).exists():
+                CorpMembershipRep.objects.create(
+                        corp_profile=self.corp_profile,
+                        user=self.creator,
+                        is_dues_rep=True
+                                )
+
+            corp_membership_update_perms(self)
 
             # update invoice creator/owner
             if self.invoice:
@@ -1089,7 +1132,7 @@ class CorpMembershipApp(TendenciBaseModel):
                             help_text=_("App for individual memberships."),
                             related_name='corp_app',
                             verbose_name=_("Membership Application"),
-                            null=True)
+                            default=1)
     payment_methods = models.ManyToManyField(PaymentMethod,
                                              verbose_name="Payment Methods")
 
@@ -1105,13 +1148,26 @@ class CorpMembershipApp(TendenciBaseModel):
 
     @models.permalink
     def get_absolute_url(self):
-        return ("corpmembership_app.preview", [self.id])
+        return ("corpmembership_app.preview", [self.slug])
+
+    def is_current(self):
+        """
+        Check if this app is the current app.
+        Corporate memberships do not support multiple apps.
+        """
+        current_app = CorpMembershipApp.objects.current_app()
+
+        return current_app and current_app.id == self.id
 
     def save(self, *args, **kwargs):
         if not self.id:
             self.guid = str(uuid.uuid1())
         super(CorpMembershipApp, self).save(*args, **kwargs)
 
+        if not self.memb_app.use_for_corp:
+            self.memb_app.use_for_corp = True
+            self.memb_app.save()
+
 
 class CorpMembershipAppField(models.Model):
     corp_app = models.ForeignKey("CorpMembershipApp", related_name="fields")
