@@ -6,7 +6,7 @@ urlpatterns = patterns('tendenci.addons.corporate_memberships.views',
         "get_app_fields_json",
         name="corpmemberships.get_app_fields"),
 
-    url(r"^applications/(?P<app_id>\d+)/preview/$",
+    url(r"^applications/(?P<slug>[\w\-]+)/preview/$",
         "app_preview",
         name="corpmembership_app.preview"),
     url(r"^applications/add_pre/$",
@@ -15,6 +15,9 @@ urlpatterns = patterns('tendenci.addons.corporate_memberships.views',
     url(r"^applications/add/$",
         "corpmembership_add",
         name="corpmembership.add"),
+    url(r"^(?P<slug>[\w\-]+)/add/$",
+        "corpmembership_add",
+        name="corpmembership.add"),
     url(r"^applications/add_conf/(?P<id>\d+)/$",
         "corpmembership_add_conf",
         name="corpmembership.add_conf"),
@@ -86,7 +89,7 @@ urlpatterns = patterns('tendenci.addons.corporate_memberships.views',
 
 # To Be Deleted
     url(r"^(?P<slug>.*)/add_pre/$", "add_pre", name="corp_memb.add_pre"),
-    url(r"^(?P<slug>.*)/add/$", "add", name="corp_memb.add"),
+    #url(r"^(?P<slug>.*)/add/$", "add", name="corp_memb.add"),
     url(r"^(?P<slug>.*)/add/(?P<hash>[\d\w]+)$", "add",
         name="corp_memb.anonymous_add"),
     url(r"^add_conf/(?P<id>\d+)/$", "add_conf", name="corp_memb.add_conf"),
