@@ -15,6 +15,7 @@ from django.http import HttpResponseRedirect
 
 from tendenci.addons.memberships.forms import MembershipTypeForm
 from tendenci.apps.user_groups.models import Group
+from tendenci.core.base.utils import tcurrency
 from tendenci.core.perms.utils import update_perms_and_save
 from tendenci.addons.memberships.models import (Membership, MembershipDefault,
                                                 MembershipType, Notice,
@@ -216,7 +217,8 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
     )
 
     def get_fieldsets(self, request, instance=None):
-        demographics_fields = get_selected_demographic_field_names()
+        demographics_fields = get_selected_demographic_field_names(
+                                        instance and instance.app)
 
         if demographics_fields:
             demographics = (
@@ -252,6 +254,23 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
         return instance.get_status().capitalize()
     get_status.short_description = u'Status'
 
+    def get_invoice(self, instance):
+        if instance.get_invoice():
+            if instance.get_invoice().balance > 0:
+                return '<a href="%s">Invoice %s (%s)</a>' % (
+                    instance.get_invoice().get_absolute_url(),
+                    instance.get_invoice().pk,
+                    tcurrency(instance.get_invoice().balance)
+                )
+            else:
+                return '<a href="%s">Invoice %s</a>' % (
+                    instance.get_invoice().get_absolute_url(),
+                    instance.get_invoice().pk
+                )
+        return ""
+    get_invoice.short_description = u'Invoice'
+    get_invoice.allow_tags = True
+
     def get_create_dt(self, instance):
         return instance.create_dt.strftime('%b %d, %Y, %I:%M %p')
     get_create_dt.short_description = u'Created On'
@@ -280,9 +299,10 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
         'name',
         'email',
         'member_number',
-        'membership_type',
+        'membership_type_link',
         'get_approve_dt',
         'get_status',
+        'get_invoice',
     ]
 
     list_filter = [
@@ -307,9 +327,26 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
         """
         Intercept add page and redirect to form.
         """
-        return HttpResponseRedirect(
-            reverse('membership_default.add')
-        )
+        apps = MembershipApp.objects.filter(
+                                status=True,
+                                status_detail__in=['published',
+                                                   'active']
+                                            )
+        count = apps.count()
+        if count == 1:
+            app = apps[0]
+            if app.use_for_corp:
+                return HttpResponseRedirect(
+                    reverse('membership_default.corp_pre_add')
+                )
+            else:
+                return HttpResponseRedirect(
+                    reverse('membership_default.add', args=[app.slug])
+                )
+        else:
+            return HttpResponseRedirect(
+                reverse('admin:memberships_membershipapp_changelist')
+            )
 
     def queryset(self, request):
         qs = super(MembershipDefaultAdmin, self).queryset(request)
@@ -397,10 +434,7 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
 
 class MembershipAppFieldAdmin(admin.TabularInline):
     model = MembershipAppField
-    fields = ('label', 'field_name', 'display',
-              'required', 'admin_only', 'order',
-              )
-#    readonly_fields = ('field_name',)
+    fields = ('label', 'field_name', 'display', 'required', 'admin_only', 'order',)
     extra = 0
     can_delete = False
     verbose_name = 'Section Break'
@@ -411,11 +445,11 @@ class MembershipAppFieldAdmin(admin.TabularInline):
 class MembershipAppAdmin(admin.ModelAdmin):
     inlines = (MembershipAppFieldAdmin, )
     prepopulated_fields = {'slug': ['name']}
-    list_display = ('name', 'status', 'status_detail')
+    list_display = ('name', 'application_form_link', 'status', 'status_detail')
     search_fields = ('name', 'status', 'status_detail')
     fieldsets = (
         (None, {'fields': ('name', 'slug', 'description',
-                           'confirmation_text', 'notes',
+                           'confirmation_text', 'notes', 'allow_multiple_membership',
                            'membership_types', 'payment_methods',
                            'use_for_corp', 'use_captcha',)},),
         ('Permissions', {'fields': ('allow_anonymous_view',)}),
@@ -428,11 +462,6 @@ class MembershipAppAdmin(admin.ModelAdmin):
             'status',
             'status_detail',
         )}),
-#        ('Add fields to your form', {'fields': ('app_field_selection',),
-#                                     'classes': ('mapped-fields', ),
-#                                     'description': 'The fields you ' + \
-#                                     'selected will be automatically ' + \
-#                                     'added to your form.'}),
     )
 
     form = MembershipAppForm
